from link2media.audio_download import download_audio
from link2media.count_core import cpu_threads
from link2media.quality_audio import high_quality_audio
from link2media.video_download import download_videos


import os
import logging
from pytube import YouTube
from concurrent.futures import ThreadPoolExecutor
import ffmpeg

def high_quality_audio(file_path, output_folder="LAION Debate", num_threads=None):
    with open(file_path, 'r') as file:
        links = file.readlines()

    total_links = len(links)
    print(f"TOTAL LINKS: {total_links}")
    downloaded_count = 0

    os.makedirs(output_folder, exist_ok=True)

    def process_link(link):
        try:
            yt = YouTube(link.strip())
            video_stream = yt.streams.filter(file_extension='mp4').first()
            if video_stream:
                video_stream.download(output_path=output_folder)  # Set output folder for video

                video_file_path = os.path.join(output_folder, video_stream.default_filename)
                audio_file_path = os.path.join(output_folder, video_stream.default_filename[:-4] + ".mp3")  # Adjust audio file path

                # Use ffmpeg to extract audio and save it as an MP3 file
                ffmpeg.input(video_file_path).output(audio_file_path, acodec='mp3').run()

                os.remove(video_file_path)

                return True, None
            else:
                return False, f"No suitable stream found for link {link.strip()}"

        except Exception as e:
            return False, f"Error processing link {link.strip()}: {e}"
    
    if num_threads is None:
        num_threads = os.cpu_count()
    
    print(f"NUM THREADS: {num_threads}")

    with ThreadPoolExecutor(max_workers=num_threads) as executor:
        for success, message in executor.map(process_link, links):
            if success:
                downloaded_count += 1
            else:
                print(message)

    print(f"DOWNLOADED AUDIO {downloaded_count}")
    print("All videos downloaded and converted successfully!")



import os
from pytube import YouTube
from concurrent.futures import ThreadPoolExecutor

def download_audio(file_path, output_folder="LAION Debate", num_threads=16):
    with open(file_path, 'r') as file:
        links = file.readlines()

    total_links = len(links)
    print(f"TOTAL LINKS: {total_links}")
    downloaded_count = 0

    os.makedirs(output_folder, exist_ok=True)

    def process_link(link):
        try:
            yt = YouTube(link.strip())
            # Filter the streams to find the one with the desired audio
            audio_stream = yt.streams.filter(only_audio=True).first()
            if audio_stream:
                out_file = audio_stream.download(output_path=output_folder)  # Download the audio file
                # Convert to MP3
                base, ext = os.path.splitext(out_file)
                new_file = base + '.mp3'
                os.rename(out_file, new_file)
                return True, None
            else:
                return False, f"No suitable stream found for link {link.strip()}"

        except Exception as e:
            return False, f"Error processing link {link.strip()}: {e}"
    
    print(f"NUM THREADS: {num_threads}")

    with ThreadPoolExecutor(max_workers=num_threads) as executor:
        for success, message in executor.map(process_link, links):
            if success:
                downloaded_count += 1
            else:
                print(message)

    print(f"DOWNLOADED VIDEOS: {downloaded_count}")
    print("All the audio files are downloaded!")


download_audio("02-05-2024-CAM.txt")



from setuptools import setup, find_packages

setup(
    name='link2media',
    version='1.0.0',
    author='tawsif',
    author_email='sleeping4cat@outlook.com',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[
        'pytube',
        'ffmpeg-python',
    ],
)
